@@ -187,8 +187,6 @@ def listen_handler(self):
 
             except WebSocketConnectionClosedException:
                 print("Connection closed")
-                print("Reconnecting...")
-                self.connect()
                 break
             except Exception as e:
                 print(f"Unknown error: {e}")
@@ -197,4 +195,4 @@ def listen_handler(self):
     finally:
         if self.ws:
             self.ws.close()
-            print("ws closed")
\ No newline at end of file
+            print("ws closed")
